summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/tab_contents.h
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-10 20:32:06 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-10 20:32:06 +0000
commit92edc4764d2f311440929ad4dca91f87be3b2f11 (patch)
treef4ba410c3fe7612ee830b326739fba05273a59e2 /chrome/browser/tab_contents/tab_contents.h
parentea16554e83cab7fe751cac7a0af8eaea3948c512 (diff)
downloadchromium_src-92edc4764d2f311440929ad4dca91f87be3b2f11.zip
chromium_src-92edc4764d2f311440929ad4dca91f87be3b2f11.tar.gz
chromium_src-92edc4764d2f311440929ad4dca91f87be3b2f11.tar.bz2
Switch from HWNDs to NativeViews, take 2. (First attempt was r9409, in which I missed a file.)
Review URL: http://codereview.chromium.org/20226 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@9507 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents/tab_contents.h')
-rw-r--r--chrome/browser/tab_contents/tab_contents.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h
index b23c8d5..59ad1ae 100644
--- a/chrome/browser/tab_contents/tab_contents.h
+++ b/chrome/browser/tab_contents/tab_contents.h
@@ -8,6 +8,7 @@
#include <string>
#include <vector>
+#include "base/gfx/native_widget_types.h"
#include "base/gfx/rect.h"
#include "chrome/browser/autocomplete/autocomplete_edit.h"
#include "chrome/browser/tab_contents/constrained_window.h"
@@ -343,17 +344,17 @@ class TabContents : public PageNavigator,
// Views and focus -----------------------------------------------------------
// Returns the actual window that is focused when this TabContents is shown.
- virtual HWND GetContentHWND() {
- return GetContainerHWND();
+ virtual gfx::NativeView GetContentNativeView() {
+ return GetNativeView();
}
// Tell the subclass to set up the view (e.g. create the container HWND if
// applicable) and any other create-time setup.
virtual void CreateView() {}
- // Returns the HWND associated with this TabContents. Outside of automation
- // in the context of the UI, this is required to be implemented.
- virtual HWND GetContainerHWND() const { return NULL; }
+ // Returns the NativeView associated with this TabContents. Outside of
+ // automation in the context of the UI, this is required to be implemented.
+ virtual gfx::NativeView GetNativeView() const { return NULL; }
// Returns the bounds of this TabContents in the screen coordinate system.
virtual void GetContainerBounds(gfx::Rect *out) const {